@@ -6,11 +6,14 @@
 #'
 #' @param Y A vector of outcomes.
 #' @param X A matrix or data.frame of training data predictors.
-#' @param family Not used by the function directly, but ensures compatibility with \code{SuperLearner}.
+#' @param family Not used by the function directly, but ensures compatibility
+#'  with \code{SuperLearner}.
 #' @param newX A test set of predictors.
-#' @param obsWeights Not used by the function directly, but ensures compatibility with \code{SuperLearner}.
-#' @param rangeThresh If the the range of the outcomes is smaller than this number, the method
-#' returns the empirical average of the outcomes. Used for computational expediency and stability.
+#' @param obsWeights Not used by the function directly, but ensures
+#'  compatibility with \code{SuperLearner}.
+#' @param rangeThresh If the the range of the outcomes is smaller than this
+#'  number, the method returns the empirical average of the outcomes. Used for
+#'  computational expediency and stability.
 #' @param ... Other arguments (not currently used).
 #'
 #' @importFrom np npregbw npreg
@@ -26,10 +29,10 @@
 #' Y <- X$X1 + rnorm(n)
 #' # fit npreg
 #' fit <- SL.npreg(Y = Y, X = X, newX = X)
-
+#
 SL.npreg <- function(Y, X, newX, family = gaussian(),
                      obsWeights = rep(1, length(Y)),
-                     rangeThresh=1e-7, ...) {
+                     rangeThresh = 1e-7, ...) {
   # turn off annoying messages
   options(np.messages = FALSE)
   # check range threshold
@@ -40,7 +43,8 @@ SL.npreg <- function(Y, X, newX, family = gaussian(),
     bw <- np::npregbw(
       stats::as.formula(
         paste("Y ~", paste(names(X), collapse = "+"))
-      ), data = X,
+      ),
+      data = X,
       ftol = 0.01, tol = 0.01, remin = FALSE
     )
 
@@ -77,7 +81,7 @@ SL.npreg <- function(Y, X, newX, family = gaussian(),
 #' # predict on fit
 #' newX <- data.frame(X1 = c(-1,0,1))
 #' pred <- predict(fit$fit, newdata = newX)
-
+#
 predict.SL.npreg <- function(object, newdata, ...) {
   pred <- stats::predict(object = object$object, newdata = newdata)
   pred
